Installazione di un connettore personalizzato

Dopo aver compilato e impacchettato il tuo connettore personalizzato, devi installarlo sulla tua istanza Discovery.

IBM Cloud Pak for Data IBM Software Hub

Queste informazioni si applicano solo alle distribuzioni installate.

Discovery fornisce uno script denominato manage_custom_crawler.sh per l'installazione e la disinstallazione dei connettori personalizzati. Lo script si trova nella directory scripts del file custom-crawler-docs.zip espanso, come descritto in Descrizione del file custom-crawler-docs.zip.

Installazione di un connettore

Puoi installare il connettore personalizzato sulla tua istanza di Discovery attenendoti alla seguente procedura.

  1. Assicurati di aver completato tutti i passi per creare un connettore personalizzato fino a quelli inclusi in Compilazione e creazione del pacchetto del connettore di esempio.

  2. Immetti il seguente comando dalla directory sulla tua macchina locale in cui hai creato e compilato il tuo connettore personalizzato:

    bash scripts/manage_custom_crawler.sh --endpoint {endpoint} --token {access token} deploy -n {crawler name} -f {built_connector_zip_file}
    

    in cui si specificano i valori delle seguenti variabili:

    • endpoint: URL per l'istanza del servizio. È possibile ottenere questo valore dalla sezione Informazioni sull'accesso della pagina di panoramica dell'istanza di servizio nella console amministrativa IBM Cloud Pak for Data.
    • token di accesso: Token del portatore necessario per accedere all'endpoint. È possibile ottenere questo valore dalla stessa pagina dell'endpoint.
    • nome del crawler: (facoltativo) Nome specificato per il crawler.
    • {built_connector_zip_file} è il nome del file creato in Compilazione e creazione del pacchetto del connettore di esempio.

    Ad esempio:

    bash scripts/manage_custom_crawler.sh --endpoint https://mycpd.wd40.example.com/discovery/zen40-wd/instances/1638165624521059/api --token eyJhbGciOiJSUzI1NiIsInR5cCI6IkpXVCIsImtpZCI6ImVKcV9HY29NcHF5WUFJcVByZ0x0cERRZDNQcmRiTWo5TGg0X09WOEU4MlkifP.eyJ1aXQiOiIxMDAwMzMwOTk5IiwidXNlcm5hbWUiOiJhZG1pbiIsInJvbGUiOiJBZG1pbiIsInBlcm1pc3Npb25zIjpbImFkbWluaXN0cmF0b3IiLCJjYW5fcHJvdmlzaW9uIl0sImdyb3VwcyI6WzEwMDAwXSwic3ViIjoiYWRtaW4iLCJpc3MiOiJLTk9YU1NPIiwiYXVkIjoiRFNYIiwiaWF0IjoxNjQyNzAyMDA3fQ.5oymGw7pi6tAbTMW9rcdb62G95teR2-tKyznA_wjk_G698fbx1Zl73KZKyEWcTKtyX7IJ1Px5DPdophcqS9i3bPJowHy-ioVp6DML02mscZImhvZPra-e6gwUdhSB64KArmMClo1-kZG20EclNh6-oxR447Bjdsgp7IYpkmynmw0K6vPIqmzwEhr9gAK1vWLOoVd4EoiYNuxZaSFL5byJ0mnQxXzM14w3lKQHZ91WYVKc4JnuJiSVsdpGqVz1JNFmT8D9FBqJQ4uxtshnii0f1Yh-USKCbJmMPXicU8cDtJIfheBejwenfvejUTz5rgZgymYWrGvw3G2oOx_L1Yg-Q deploy -n awesome_crawler -f awesome_crawler.zip
    

    Invece di specificare un token di accesso per l'autenticazione, è possibile specificare i parametri di nome utente e password. Per ulteriori informazioni, vedere Comprendere lo script manage_custom_crawler.sh.

Quando il crawler personalizzato viene distribuito, al connettore viene assegnato un ID risorsa.

Verifica di un connettore installato

Verificare che il connettore sia stato distribuito nell'istanza Discovery accedendo al tooling Discovery e assicurandosi che il connettore sia visualizzato come opzione nella pagina Configura collezione.

Utilizzo di un connettore installato su Discovery

Per utilizzare il connettore personalizzato installato, segui i passi elencati in Creazione di una raccolta. Il connettore personalizzato viene visualizzato nell'elenco dei connettori forniti in Configurazione delle origini dati Cloud Pak for Data. Per ulteriori informazioni, vedere Utilizzo di un connettore personalizzato con il tooling Discovery.

Disinstallazione di un connettore

Per disinstallare un connettore personalizzato da un'istanza Discovery, completare i seguenti passaggi:

  1. Opzionale: se non si conosce l'ID della risorsa, eseguire il seguente comando per elencare i connettori personalizzati. Vengono restituiti gli ID delle risorse dei connettori.

    scripts/manage_custom_crawler.sh --endpoint {endpoint} --token {token} list
    
  2. Eseguire il seguente comando dalla directory in cui è stato estratto il file ZIP del connettore personalizzato per disinstallarlo:

    scripts/manage_custom_crawler.sh --endpoint {endpoint} --token {token} undeploy --id {crawler_resource_id}
    

    dove {crawler-resource-id} è l'ID che viene generato per il crawler quando viene distribuito.

    scripts/manage_custom_crawler.sh --endpoint {endpoint} --token {token} undeploy --id {crawler_resource_id}
    

Invece di specificare un token di accesso per l'autenticazione, è possibile specificare i parametri di nome utente e password. Per ulteriori informazioni, vedere Comprendere lo script manage_custom_crawler.sh.

Descrizione dello script manage_custom_crawler.sh

Lo script manage_custom_crawler.sh ha la seguente documentazione interna:

Watson Discovery Custom Crawler Manager

This script will help you deploy, manage, and undeploy your custom crawler for
Watson Discovery.

Subcommands:
  deploy        Add a new Custom Crawler to your Watson Discovery instance.
  undeploy      Undeploy your Custom Crawler by name.
  list          List all Custom Crawlers for your Watson Discovery instance.

Options:
  -e --endpoint         The endpoint URL for your cluster and add-on service instance
                        (`https://{cpd_cluster_host}:{port}/discovery/{release}/instances/{instance_id}/api`)
  -t --token            The authorization token of your Cloud Pak instance
  -u --user             The user name of your Cloud Pak instance
  -p --password         The user password of your Cloud Pak instance
                        If the password is not specified, the command line prompts to input
  -n --name             The name of the custom crawler to upload (deploy only)
  -f --file             The path of the custom crawler package to upload (deploy only)
  -i --id               The crawler_resource_id value to delete the custom crawler (undeploy only)
  --help                Show this message.

4.0.5 e solo versioni precedenti

Installazione di un connettore in 4.0.5 e versioni precedenti

Puoi installare il connettore personalizzato sulla tua istanza di Discovery attenendoti alla seguente procedura.

  1. Assicurati di aver completato tutti i passi per creare un connettore personalizzato fino a quelli inclusi in Compilazione e creazione del pacchetto del connettore di esempio.

  2. Immetti il seguente comando dalla directory sulla tua macchina locale in cui hai creato e compilato il tuo connettore personalizzato:

    bash scripts/manage_custom_crawler.sh deploy -z {built_connector_zip_file}
    

    dove {built_connector_zip_file} è il nome del file che hai impacchettato in Compilazione e creazione del pacchetto del connettore di esempio.

    Se l'istanza di Discovery è in esecuzione su Red Hat OpenShift, specificare il parametro -o o --openshift con lo script.

    Ad esempio:

    bash scripts/manage_custom_crawler.sh deploy -z myCrawler.zip -o true
    

Disinstallazione di un connettore in 4.0.5 e versioni precedenti

Per disinstallare un connettore personalizzato da un'istanza Discovery, immetti il seguente comando alla root della directory custom-crawler-docs.zip decompressa:

bash scripts/manage_custom_crawler.sh undeploy -n {built_connector_name}

dove {build_connector_name} è il nome, non il file .zip, del connettore installato.

Se l'istanza di IBM Watson® Discovery è in esecuzione su Red Hat OpenShift, specificare il parametro -o o --openshift con lo script.

bash scripts/manage_custom_crawler.sh undeploy -n {built_connector_name} -o true

Comprensione dello script manage_custom_crawler.sh in 4.0.5 e versioni precedenti

Lo script manage_custom_crawler.sh ha la seguente documentazione interna:

Usage: ${BASH_SOURCE[0]} [--pathToZip PATH] [--properties PROPERTIES] [--xml XML]

Watson Discovery Custom Crawler Manager

This script will help you deploy, manage, and undeploy your custom crawler for
Watson Discovery.

Subcommands:
  deploy        Add a new Custom Crawler to your Watson Discovery instance.
  properties    Generate the properties file for your crawler.
  undeploy      Undeploy your Custom Crawler by name.
  list          List all Custom Crawlers for your Watson Discovery instance.

Options:
  -d --discovery        The name of the Watson Discovery instance
  -z --zipfile          The path to the zip file to be uploaded.
                        For deploy only.
  -x --xml              The path to the XML file to be uploaded.
                        For deploy only.
  -n --name             The name of the Custom Crawler to undeploy.
  -m --messages         The path to the properties file, used when doing a two part deploy.
                        For properties only.
  -o --openshift        Set flag to true if this is an OpenShift Cluster
  --help                Show this message.